Struct rusty_v8::BigInt [−][src]
#[repr(C)]pub struct BigInt(_);
A JavaScript BigInt value (https://tc39.github.io/proposal-bigint)
Implementations
impl BigInt[src]
impl BigInt[src]pub fn new_from_i64<'s>(
scope: &mut HandleScope<'s>,
value: i64
) -> Local<'s, BigInt>[src]
scope: &mut HandleScope<'s>,
value: i64
) -> Local<'s, BigInt>
pub fn new_from_u64<'s>(
scope: &mut HandleScope<'s>,
value: u64
) -> Local<'s, BigInt>[src]
scope: &mut HandleScope<'s>,
value: u64
) -> Local<'s, BigInt>
pub fn new_from_words<'s>(
scope: &mut HandleScope<'s>,
sign_bit: bool,
words: &[u64]
) -> Option<Local<'s, BigInt>>[src]
pub fn new_from_words<'s>(
scope: &mut HandleScope<'s>,
sign_bit: bool,
words: &[u64]
) -> Option<Local<'s, BigInt>>[src]Creates a new BigInt object using a specified sign bit and a specified list of digits/words. The resulting number is calculated as:
(-1)^sign_bit * (words[0] * (2^64)^0 + words[1] * (2^64)^1 + …)
pub fn u64_value(&self) -> (u64, bool)[src]
pub fn u64_value(&self) -> (u64, bool)[src]Returns the value of this BigInt as an unsigned 64-bit integer, and a
bool indicating whether the return value was truncated was truncated or
wrapped around. In particular, it will be false if this BigInt is
negative.
pub fn i64_value(&self) -> (i64, bool)[src]
pub fn i64_value(&self) -> (i64, bool)[src]Returns the value of this BigInt as a signed 64-bit integer, and a bool
indicating whether this BigInt was truncated or not.
pub fn word_count(&self) -> usize[src]
pub fn word_count(&self) -> usize[src]Returns the number of 64-bit words needed to store the result of
to_words_array.
Methods from Deref<Target = Value>
pub fn is_undefined(&self) -> bool[src]
pub fn is_undefined(&self) -> bool[src]Returns true if this value is the undefined value. See ECMA-262 4.3.10.
pub fn is_null(&self) -> bool[src]
pub fn is_null(&self) -> bool[src]Returns true if this value is the null value. See ECMA-262 4.3.11.
pub fn is_null_or_undefined(&self) -> bool[src]
pub fn is_null_or_undefined(&self) -> bool[src]Returns true if this value is either the null or the undefined value. See ECMA-262 4.3.11. and 4.3.12
pub fn is_true(&self) -> bool[src]
pub fn is_true(&self) -> bool[src]Returns true if this value is true.
This is not the same as BooleanValue(). The latter performs a
conversion to boolean, i.e. the result of Boolean(value) in JS, whereas
this checks value === true.
pub fn is_false(&self) -> bool[src]
pub fn is_false(&self) -> bool[src]Returns true if this value is false.
This is not the same as !BooleanValue(). The latter performs a
conversion to boolean, i.e. the result of !Boolean(value) in JS, whereas
this checks value === false.
pub fn is_name(&self) -> bool[src]
pub fn is_name(&self) -> bool[src]Returns true if this value is a symbol or a string.
This is equivalent to
typeof value === 'string' || typeof value === 'symbol' in JS.
pub fn is_string(&self) -> bool[src]
pub fn is_string(&self) -> bool[src]Returns true if this value is an instance of the String type. See ECMA-262 8.4.
pub fn is_symbol(&self) -> bool[src]
pub fn is_symbol(&self) -> bool[src]Returns true if this value is a symbol.
This is equivalent to typeof value === 'symbol' in JS.
pub fn is_function(&self) -> bool[src]
pub fn is_function(&self) -> bool[src]Returns true if this value is a function.
pub fn is_array(&self) -> bool[src]
pub fn is_array(&self) -> bool[src]Returns true if this value is an array. Note that it will return false for an Proxy for an array.
pub fn is_big_int(&self) -> bool[src]
pub fn is_big_int(&self) -> bool[src]Returns true if this value is a bigint.
This is equivalent to typeof value === 'bigint' in JS.
pub fn is_boolean(&self) -> bool[src]
pub fn is_boolean(&self) -> bool[src]Returns true if this value is boolean.
This is equivalent to typeof value === 'boolean' in JS.
pub fn is_external(&self) -> bool[src]
pub fn is_external(&self) -> bool[src]Returns true if this value is an External object.
pub fn is_arguments_object(&self) -> bool[src]
pub fn is_arguments_object(&self) -> bool[src]Returns true if this value is an Arguments object.
pub fn is_big_int_object(&self) -> bool[src]
pub fn is_big_int_object(&self) -> bool[src]Returns true if this value is a BigInt object.
pub fn is_boolean_object(&self) -> bool[src]
pub fn is_boolean_object(&self) -> bool[src]Returns true if this value is a Boolean object.
pub fn is_number_object(&self) -> bool[src]
pub fn is_number_object(&self) -> bool[src]Returns true if this value is a Number object.
pub fn is_string_object(&self) -> bool[src]
pub fn is_string_object(&self) -> bool[src]Returns true if this value is a String object.
pub fn is_symbol_object(&self) -> bool[src]
pub fn is_symbol_object(&self) -> bool[src]Returns true if this value is a Symbol object.
pub fn is_native_error(&self) -> bool[src]
pub fn is_native_error(&self) -> bool[src]Returns true if this value is a NativeError.
pub fn is_reg_exp(&self) -> bool[src]
pub fn is_reg_exp(&self) -> bool[src]Returns true if this value is a RegExp.
pub fn is_async_function(&self) -> bool[src]
pub fn is_async_function(&self) -> bool[src]Returns true if this value is an async function.
pub fn is_generator_function(&self) -> bool[src]
pub fn is_generator_function(&self) -> bool[src]Returns true if this value is a Generator function.
pub fn is_promise(&self) -> bool[src]
pub fn is_promise(&self) -> bool[src]Returns true if this value is a Promise.
pub fn is_map_iterator(&self) -> bool[src]
pub fn is_map_iterator(&self) -> bool[src]Returns true if this value is a Map Iterator.
pub fn is_set_iterator(&self) -> bool[src]
pub fn is_set_iterator(&self) -> bool[src]Returns true if this value is a Set Iterator.
pub fn is_weak_map(&self) -> bool[src]
pub fn is_weak_map(&self) -> bool[src]Returns true if this value is a WeakMap.
pub fn is_weak_set(&self) -> bool[src]
pub fn is_weak_set(&self) -> bool[src]Returns true if this value is a WeakSet.
pub fn is_array_buffer(&self) -> bool[src]
pub fn is_array_buffer(&self) -> bool[src]Returns true if this value is an ArrayBuffer.
pub fn is_array_buffer_view(&self) -> bool[src]
pub fn is_array_buffer_view(&self) -> bool[src]Returns true if this value is an ArrayBufferView.
pub fn is_typed_array(&self) -> bool[src]
pub fn is_typed_array(&self) -> bool[src]Returns true if this value is one of TypedArrays.
pub fn is_uint8_array(&self) -> bool[src]
pub fn is_uint8_array(&self) -> bool[src]Returns true if this value is an Uint8Array.
pub fn is_uint8_clamped_array(&self) -> bool[src]
pub fn is_uint8_clamped_array(&self) -> bool[src]Returns true if this value is an Uint8ClampedArray.
pub fn is_int8_array(&self) -> bool[src]
pub fn is_int8_array(&self) -> bool[src]Returns true if this value is an Int8Array.
pub fn is_uint16_array(&self) -> bool[src]
pub fn is_uint16_array(&self) -> bool[src]Returns true if this value is an Uint16Array.
pub fn is_int16_array(&self) -> bool[src]
pub fn is_int16_array(&self) -> bool[src]Returns true if this value is an Int16Array.
pub fn is_uint32_array(&self) -> bool[src]
pub fn is_uint32_array(&self) -> bool[src]Returns true if this value is an Uint32Array.
pub fn is_int32_array(&self) -> bool[src]
pub fn is_int32_array(&self) -> bool[src]Returns true if this value is an Int32Array.
pub fn is_float32_array(&self) -> bool[src]
pub fn is_float32_array(&self) -> bool[src]Returns true if this value is a Float32Array.
pub fn is_float64_array(&self) -> bool[src]
pub fn is_float64_array(&self) -> bool[src]Returns true if this value is a Float64Array.
pub fn is_big_int64_array(&self) -> bool[src]
pub fn is_big_int64_array(&self) -> bool[src]Returns true if this value is a BigInt64Array.
pub fn is_big_uint64_array(&self) -> bool[src]
pub fn is_big_uint64_array(&self) -> bool[src]Returns true if this value is a BigUint64Array.
pub fn is_data_view(&self) -> bool[src]
pub fn is_data_view(&self) -> bool[src]Returns true if this value is a DataView.
pub fn is_shared_array_buffer(&self) -> bool[src]
pub fn is_shared_array_buffer(&self) -> bool[src]Returns true if this value is a SharedArrayBuffer. This is an experimental feature.
pub fn is_wasm_module_object(&self) -> bool[src]
pub fn is_wasm_module_object(&self) -> bool[src]Returns true if this value is a WasmModuleObject.
pub fn is_module_namespace_object(&self) -> bool[src]
pub fn is_module_namespace_object(&self) -> bool[src]Returns true if the value is a Module Namespace Object.
pub fn strict_equals(&self, that: Local<'_, Value>) -> bool[src]
pub fn same_value(&self, that: Local<'_, Value>) -> bool[src]
pub fn same_value_zero(&self, that: Local<'_, Value>) -> bool[src]
pub fn same_value_zero(&self, that: Local<'_, Value>) -> bool[src]Implements the the abstract operation SameValueZero, which is defined in
ECMA-262 6th edition  7.2.10
(http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero).
This operation is used to compare values for the purpose of insertion into
a Set, or determining whether Map keys are equivalent. Its semantics
are almost the same as strict_equals() and same_value(), with the
following important distinctions:
- It considers
NaNequal toNaN(unlikestrict_equals()). - It considers
-0equal to0(unlikesame_value()).
pub fn to_big_int<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, BigInt>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, BigInt>>
pub fn to_number<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Number>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Number>>
pub fn to_string<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>
pub fn to_rust_string_lossy<'s>(&self, scope: &mut HandleScope<'s>) -> String[src]
pub fn to_rust_string_lossy<'s>(&self, scope: &mut HandleScope<'s>) -> String[src]Convenience function not present in the original V8 API.
pub fn to_detail_string<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>
pub fn to_object<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Object>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Object>>
pub fn to_integer<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Integer>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Integer>>
pub fn to_uint32<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Uint32>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Uint32>>
pub fn to_int32<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Int32>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Int32>>
pub fn to_boolean<'s>(
&self,
scope: &mut HandleScope<'s, ()>
) -> Local<'s, Boolean>[src]
pub fn to_boolean<'s>(
&self,
scope: &mut HandleScope<'s, ()>
) -> Local<'s, Boolean>[src]Perform the equivalent of Boolean(value) in JS. This can never fail.
pub fn number_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<f64>[src]
pub fn integer_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<i64>[src]
pub fn uint32_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<u32>[src]
pub fn int32_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<i32>[src]
pub fn boolean_value<'s>(&self, scope: &mut HandleScope<'s, ()>) -> bool[src]
Methods from Deref<Target = Data>
pub fn get_hash(&self) -> int[src]
pub fn get_hash(&self) -> int[src]Returns the V8 hash value for this value. The current implementation uses a hidden property to store the identity hash on some object types.
The return value will never be 0. Also, it is not guaranteed to be unique.
pub fn is_private(&self) -> bool[src]
pub fn is_private(&self) -> bool[src]Returns true if this data is a Private.
pub fn is_object_template(&self) -> bool[src]
pub fn is_object_template(&self) -> bool[src]Returns true if this data is an ObjectTemplate
pub fn is_function_template(&self) -> bool[src]
pub fn is_function_template(&self) -> bool[src]Returns true if this data is a FunctionTemplate.