Struct rusty_v8::String [−][src]
A JavaScript string value (ECMA-262, 4.3.17).
Implementations
impl String[src]
pub fn empty<'s>(scope: &mut HandleScope<'s, ()>) -> Local<'s, String>[src]
pub fn new_from_utf8<'s>(
scope: &mut HandleScope<'s, ()>,
buffer: &[u8],
new_type: NewStringType
) -> Option<Local<'s, String>>[src]
scope: &mut HandleScope<'s, ()>,
buffer: &[u8],
new_type: NewStringType
) -> Option<Local<'s, String>>
Allocates a new string from UTF-8 data. Only returns an empty value when length > kMaxLength
pub fn new_from_one_byte<'s>(
scope: &mut HandleScope<'s, ()>,
buffer: &[u8],
new_type: NewStringType
) -> Option<Local<'s, String>>[src]
scope: &mut HandleScope<'s, ()>,
buffer: &[u8],
new_type: NewStringType
) -> Option<Local<'s, String>>
Allocates a new string from Latin-1 data. Only returns an empty value when length > kMaxLength.
pub fn length(&self) -> usize[src]
Returns the number of characters (UTF-16 code units) in this string.
pub fn utf8_length(&self, scope: &mut Isolate) -> usize[src]
Returns the number of bytes in the UTF-8 encoded representation of this string.
pub fn write_utf8(
&self,
scope: &mut Isolate,
buffer: &mut [u8],
nchars_ref: Option<&mut usize>,
options: WriteOptions
) -> usize[src]
&self,
scope: &mut Isolate,
buffer: &mut [u8],
nchars_ref: Option<&mut usize>,
options: WriteOptions
) -> usize
pub fn new<'s>(
scope: &mut HandleScope<'s, ()>,
value: &str
) -> Option<Local<'s, String>>[src]
scope: &mut HandleScope<'s, ()>,
value: &str
) -> Option<Local<'s, String>>
pub fn new_external_onebyte_static<'s>(
scope: &mut HandleScope<'s, ()>,
buffer: &'static [u8]
) -> Option<Local<'s, String>>[src]
scope: &mut HandleScope<'s, ()>,
buffer: &'static [u8]
) -> Option<Local<'s, String>>
pub fn is_external(&self) -> bool[src]
True if string is external
pub fn is_external_onebyte(&self) -> bool[src]
True if string is external & one-byte (e.g: created with new_external_onebyte_static)
pub fn is_external_twobyte(&self) -> bool[src]
True if string is external & two-byte NOTE: can’t yet be created via rusty_v8
pub fn is_onebyte(&self) -> bool[src]
True if string is known to contain only one-byte data doesn’t read the string so can return false positives
pub fn to_rust_string_lossy(&self, scope: &mut Isolate) -> String[src]
Convenience function not present in the original V8 API.
Methods from Deref<Target = Value>
pub fn is_undefined(&self) -> bool[src]
Returns true if this value is the undefined value. See ECMA-262 4.3.10.
pub fn is_null(&self) -> bool[src]
Returns true if this value is the null value. See ECMA-262 4.3.11.
pub fn is_null_or_undefined(&self) -> bool[src]
Returns true if this value is either the null or the undefined value. See ECMA-262 4.3.11. and 4.3.12
pub fn is_true(&self) -> bool[src]
Returns true if this value is true.
This is not the same as BooleanValue(). The latter performs a
conversion to boolean, i.e. the result of Boolean(value) in JS, whereas
this checks value === true.
pub fn is_false(&self) -> bool[src]
Returns true if this value is false.
This is not the same as !BooleanValue(). The latter performs a
conversion to boolean, i.e. the result of !Boolean(value) in JS, whereas
this checks value === false.
pub fn is_name(&self) -> bool[src]
Returns true if this value is a symbol or a string.
This is equivalent to
typeof value === 'string' || typeof value === 'symbol' in JS.
pub fn is_string(&self) -> bool[src]
Returns true if this value is an instance of the String type. See ECMA-262 8.4.
pub fn is_symbol(&self) -> bool[src]
Returns true if this value is a symbol.
This is equivalent to typeof value === 'symbol' in JS.
pub fn is_function(&self) -> bool[src]
Returns true if this value is a function.
pub fn is_array(&self) -> bool[src]
Returns true if this value is an array. Note that it will return false for an Proxy for an array.
pub fn is_object(&self) -> bool[src]
Returns true if this value is an object.
pub fn is_big_int(&self) -> bool[src]
Returns true if this value is a bigint.
This is equivalent to typeof value === 'bigint' in JS.
pub fn is_boolean(&self) -> bool[src]
Returns true if this value is boolean.
This is equivalent to typeof value === 'boolean' in JS.
pub fn is_number(&self) -> bool[src]
Returns true if this value is a number.
pub fn is_external(&self) -> bool[src]
Returns true if this value is an External object.
pub fn is_int32(&self) -> bool[src]
Returns true if this value is a 32-bit signed integer.
pub fn is_uint32(&self) -> bool[src]
Returns true if this value is a 32-bit unsigned integer.
pub fn is_date(&self) -> bool[src]
Returns true if this value is a Date.
pub fn is_arguments_object(&self) -> bool[src]
Returns true if this value is an Arguments object.
pub fn is_big_int_object(&self) -> bool[src]
Returns true if this value is a BigInt object.
pub fn is_boolean_object(&self) -> bool[src]
Returns true if this value is a Boolean object.
pub fn is_number_object(&self) -> bool[src]
Returns true if this value is a Number object.
pub fn is_string_object(&self) -> bool[src]
Returns true if this value is a String object.
pub fn is_symbol_object(&self) -> bool[src]
Returns true if this value is a Symbol object.
pub fn is_native_error(&self) -> bool[src]
Returns true if this value is a NativeError.
pub fn is_reg_exp(&self) -> bool[src]
Returns true if this value is a RegExp.
pub fn is_async_function(&self) -> bool[src]
Returns true if this value is an async function.
pub fn is_generator_function(&self) -> bool[src]
Returns true if this value is a Generator function.
pub fn is_promise(&self) -> bool[src]
Returns true if this value is a Promise.
pub fn is_map(&self) -> bool[src]
Returns true if this value is a Map.
pub fn is_set(&self) -> bool[src]
Returns true if this value is a Set.
pub fn is_map_iterator(&self) -> bool[src]
Returns true if this value is a Map Iterator.
pub fn is_set_iterator(&self) -> bool[src]
Returns true if this value is a Set Iterator.
pub fn is_weak_map(&self) -> bool[src]
Returns true if this value is a WeakMap.
pub fn is_weak_set(&self) -> bool[src]
Returns true if this value is a WeakSet.
pub fn is_array_buffer(&self) -> bool[src]
Returns true if this value is an ArrayBuffer.
pub fn is_array_buffer_view(&self) -> bool[src]
Returns true if this value is an ArrayBufferView.
pub fn is_typed_array(&self) -> bool[src]
Returns true if this value is one of TypedArrays.
pub fn is_uint8_array(&self) -> bool[src]
Returns true if this value is an Uint8Array.
pub fn is_uint8_clamped_array(&self) -> bool[src]
Returns true if this value is an Uint8ClampedArray.
pub fn is_int8_array(&self) -> bool[src]
Returns true if this value is an Int8Array.
pub fn is_uint16_array(&self) -> bool[src]
Returns true if this value is an Uint16Array.
pub fn is_int16_array(&self) -> bool[src]
Returns true if this value is an Int16Array.
pub fn is_uint32_array(&self) -> bool[src]
Returns true if this value is an Uint32Array.
pub fn is_int32_array(&self) -> bool[src]
Returns true if this value is an Int32Array.
pub fn is_float32_array(&self) -> bool[src]
Returns true if this value is a Float32Array.
pub fn is_float64_array(&self) -> bool[src]
Returns true if this value is a Float64Array.
pub fn is_big_int64_array(&self) -> bool[src]
Returns true if this value is a BigInt64Array.
pub fn is_big_uint64_array(&self) -> bool[src]
Returns true if this value is a BigUint64Array.
pub fn is_data_view(&self) -> bool[src]
Returns true if this value is a DataView.
pub fn is_shared_array_buffer(&self) -> bool[src]
Returns true if this value is a SharedArrayBuffer. This is an experimental feature.
pub fn is_proxy(&self) -> bool[src]
Returns true if this value is a JavaScript Proxy.
pub fn is_wasm_module_object(&self) -> bool[src]
Returns true if this value is a WasmModuleObject.
pub fn is_module_namespace_object(&self) -> bool[src]
Returns true if the value is a Module Namespace Object.
pub fn strict_equals(&self, that: Local<'_, Value>) -> bool[src]
pub fn same_value(&self, that: Local<'_, Value>) -> bool[src]
pub fn same_value_zero(&self, that: Local<'_, Value>) -> bool[src]
Implements the the abstract operation SameValueZero, which is defined in
ECMA-262 6th edition  7.2.10
(http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero).
This operation is used to compare values for the purpose of insertion into
a Set, or determining whether Map keys are equivalent. Its semantics
are almost the same as strict_equals() and same_value(), with the
following important distinctions:
- It considers
NaNequal toNaN(unlikestrict_equals()). - It considers
-0equal to0(unlikesame_value()).
pub fn to_big_int<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, BigInt>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, BigInt>>
pub fn to_number<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Number>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Number>>
pub fn to_string<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>
pub fn to_rust_string_lossy<'s>(&self, scope: &mut HandleScope<'s>) -> String[src]
Convenience function not present in the original V8 API.
pub fn to_detail_string<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, String>>
pub fn to_object<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Object>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Object>>
pub fn to_integer<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Integer>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Integer>>
pub fn to_uint32<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Uint32>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Uint32>>
pub fn to_int32<'s>(
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Int32>>[src]
&self,
scope: &mut HandleScope<'s>
) -> Option<Local<'s, Int32>>
pub fn to_boolean<'s>(
&self,
scope: &mut HandleScope<'s, ()>
) -> Local<'s, Boolean>[src]
&self,
scope: &mut HandleScope<'s, ()>
) -> Local<'s, Boolean>
Perform the equivalent of Boolean(value) in JS. This can never fail.
pub fn number_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<f64>[src]
pub fn integer_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<i64>[src]
pub fn uint32_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<u32>[src]
pub fn int32_value<'s>(&self, scope: &mut HandleScope<'s>) -> Option<i32>[src]
pub fn boolean_value<'s>(&self, scope: &mut HandleScope<'s, ()>) -> bool[src]
Methods from Deref<Target = Data>
pub fn get_hash(&self) -> int[src]
Returns the V8 hash value for this value. The current implementation uses a hidden property to store the identity hash on some object types.
The return value will never be 0. Also, it is not guaranteed to be unique.
pub fn is_value(&self) -> bool[src]
Returns true if this data is a Value.
pub fn is_module(&self) -> bool[src]
Returns true if this data is a Module.
pub fn is_private(&self) -> bool[src]
Returns true if this data is a Private.
pub fn is_object_template(&self) -> bool[src]
Returns true if this data is an ObjectTemplate
pub fn is_function_template(&self) -> bool[src]
Returns true if this data is a FunctionTemplate.